.. :changelog:

History
=======

[Unreleased]
------------

0.2.0 (2018-12-21)
------------------

Added
~~~~~

* Django REST framework 3.9, Python 3.7 & Django 2.1.
* Set long description content type to reStructuredText.

0.1.0 (2018-07-02)
------------------

Added
~~~~~

* First release on PyPI.
